# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_marketingmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_storebrowse_pb2 as steammessages__storebrowse__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_marketingmessages.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%steammessages_marketingmessages.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x1fsteammessages_storebrowse.proto\"H\n5CMarketingMessages_GetActiveMarketingMessages_Request\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\"\xed\x05\n\x16\x43MarketingMessageProto\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x04type\x18\x03 \x01(\x0e\x32\x16.EMarketingMessageType:\x1ak_EMarketingMessageInvalid\x12P\n\nvisibility\x18\x04 \x01(\x0e\x32\x1c.EMarketingMessageVisibility:\x1ek_EMarketingMessageVisibleBeta\x12\x10\n\x08priority\x18\x05 \x01(\r\x12]\n\x10\x61ssociation_type\x18\x06 \x01(\x0e\x32!.EMarketingMessageAssociationType: k_EMarketingMessageNoAssociation\x12\x15\n\rassociated_id\x18\x07 \x01(\r\x12\x17\n\x0f\x61ssociated_name\x18\x08 \x01(\t\x12\x12\n\nstart_date\x18\t \x01(\r\x12\x10\n\x08\x65nd_date\x18\n \x01(\r\x12\x15\n\rcountry_allow\x18\x0b \x01(\t\x12\x14\n\x0c\x63ountry_deny\x18\x0c \x01(\t\x12)\n!ownership_restrictions_overridden\x18\r \x01(\x08\x12\x16\n\x0emust_own_appid\x18\x0e \x01(\r\x12\x1a\n\x12must_not_own_appid\x18\x0f \x01(\r\x12\x1a\n\x12must_own_packageid\x18\x10 \x01(\r\x12\x1e\n\x16must_not_own_packageid\x18\x11 \x01(\r\x12 \n\x18must_have_launched_appid\x18\x12 \x01(\r\x12\x1f\n\x17\x61\x64\x64itional_restrictions\x18\x13 \x01(\t\x12\x15\n\rtemplate_type\x18\x14 \x01(\t\x12\x15\n\rtemplate_vars\x18\x15 \x01(\t\x12\r\n\x05\x66lags\x18\x16 \x01(\r\x12\x14\n\x0c\x63reator_name\x18\x17 \x01(\t\"\x82\x01\n6CMarketingMessages_GetActiveMarketingMessages_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto\x12\x1d\n\x15time_next_message_age\x18\x02 \x01(\r\"\x9f\x03\n6CMarketingMessages_GetMarketingMessagesForUser_Request\x12\x1d\n\x15include_seen_messages\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x11\n\telanguage\x18\x03 \x01(\x05\x12\x31\n\x10operating_system\x18\x04 \x01(\x05\x42\x17\x82\xb5\x18\x13\x45OSType from client\x12\x1e\n\x16\x63lient_package_version\x18\x05 \x01(\x05\x12l\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x13.StoreBrowseContextBF\x82\xb5\x18\x42Optional, server can fill in from country code/language if not set\x12\\\n\x0c\x64\x61ta_request\x18\x07 \x01(\x0b\x32\x1b.StoreBrowseItemDataRequestB)\x82\xb5\x18%If passed, item data will be returned\"\x93\x02\n\x18\x43\x44isplayMarketingMessage\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x04type\x18\x03 \x01(\x0e\x32\x16.EMarketingMessageType:\x1ak_EMarketingMessageInvalid\x12(\n\x12\x61ssociated_item_id\x18\x04 \x01(\x0b\x32\x0c.StoreItemID\x12#\n\x0f\x61ssociated_item\x18\x05 \x01(\x0b\x32\n.StoreItem\x12\x17\n\x0f\x61ssociated_name\x18\x06 \x01(\t\x12\x15\n\rtemplate_type\x18\n \x01(\t\x12\x1a\n\x12template_vars_json\x18\x0b \x01(\t\"\xfa\x01\n7CMarketingMessages_GetMarketingMessagesForUser_Response\x12\x62\n\x08messages\x18\x01 \x03(\x0b\x32P.CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser\x1a[\n\x17MarketingMessageForUser\x12\x14\n\x0c\x61lready_seen\x18\x01 \x01(\x08\x12*\n\x07message\x18\x02 \x01(\x0b\x32\x19.CDisplayMarketingMessage\"\xc8\x01\n5CMarketingMessages_GetDisplayMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12$\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x13.StoreBrowseContext\x12\\\n\x0c\x64\x61ta_request\x18\x03 \x01(\x0b\x32\x1b.StoreBrowseItemDataRequestB)\x82\xb5\x18%If passed, item data will be returned\"d\n6CMarketingMessages_GetDisplayMarketingMessage_Response\x12*\n\x07message\x18\x01 \x01(\x0b\x32\x19.CDisplayMarketingMessage\">\n/CMarketingMessages_MarkMessageSeen_Notification\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"=\n.CMarketingMessages_GetMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"[\n/CMarketingMessages_GetMarketingMessage_Response\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x17.CMarketingMessageProto\"]\n1CMarketingMessages_CreateMarketingMessage_Request\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x17.CMarketingMessageProto\"A\n2CMarketingMessages_CreateMarketingMessage_Response\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"j\n1CMarketingMessages_UpdateMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12(\n\x07message\x18\x02 \x01(\x0b\x32\x17.CMarketingMessageProto\"4\n2CMarketingMessages_UpdateMarketingMessage_Response\"@\n1CMarketingMessages_DeleteMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"4\n2CMarketingMessages_DeleteMarketingMessage_Response\"\xfe\x01\n0CMarketingMessages_FindMarketingMessages_Request\x12S\n\x0blookup_type\x18\x01 \x01(\x0e\x32\x1c.EMarketingMessageLookupType: k_EMarketingMessageLookupInvalid\x12\x0b\n\x03gid\x18\x02 \x01(\x06\x12H\n\x0cmessage_type\x18\x03 \x01(\x0e\x32\x16.EMarketingMessageType:\x1ak_EMarketingMessageInvalid\x12\x0f\n\x07gidlist\x18\x04 \x03(\x06\x12\r\n\x05title\x18\x05 \x01(\t\"^\n1CMarketingMessages_FindMarketingMessages_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto*\xea\x02\n\x15\x45MarketingMessageType\x12\x1e\n\x1ak_EMarketingMessageInvalid\x10\x00\x12#\n\x1fk_EMarketingMessageNowAvailable\x10\x01\x12\"\n\x1ek_EMarketingMessageWeekendDeal\x10\x02\x12\"\n\x1ek_EMarketingMessagePrePurchase\x10\x03\x12\x1e\n\x1ak_EMarketingMessagePlayNow\x10\x04\x12!\n\x1dk_EMarketingMessagePreloadNow\x10\x05\x12\x1e\n\x1ak_EMarketingMessageGeneral\x10\x06\x12\x1f\n\x1bk_EMarketingMessageDemoQuit\x10\x07\x12\x1e\n\x1ak_EMarketingMessageGifting\x10\x08\x12 \n\x1ck_EMarketingMessageEJsKorner\x10\t*g\n\x1b\x45MarketingMessageVisibility\x12\"\n\x1ek_EMarketingMessageVisibleBeta\x10\x01\x12$\n k_EMarketingMessageVisiblePublic\x10\x02*\x9f\x02\n EMarketingMessageAssociationType\x12$\n k_EMarketingMessageNoAssociation\x10\x00\x12%\n!k_EMarketingMessageAppAssociation\x10\x01\x12.\n*k_EMarketingMessageSubscriptionAssociation\x10\x02\x12+\n\'k_EMarketingMessagePublisherAssociation\x10\x03\x12\'\n#k_EMarketingMessageGenreAssociation\x10\x04\x12(\n$k_EMarketingMessageBundleAssociation\x10\x05*\xe2\x01\n\x1b\x45MarketingMessageLookupType\x12$\n k_EMarketingMessageLookupInvalid\x10\x00\x12\"\n\x1ek_EMarketingMessageLookupByGID\x10\x01\x12#\n\x1fk_EMarketingMessageLookupActive\x10\x02\x12,\n(k_EMarketingMessageLookupByTitleWithType\x10\x03\x12&\n\"k_EMarketingMessageLookupByGIDList\x10\x04\x32\xca\r\n\x11MarketingMessages\x12\xbb\x01\n\x1aGetActiveMarketingMessages\x12\x36.CMarketingMessages_GetActiveMarketingMessages_Request\x1a\x37.CMarketingMessages_GetActiveMarketingMessages_Response\",\x82\xb5\x18(Get a list of active marketing messages.\x12\xdb\x01\n\x1bGetMarketingMessagesForUser\x12\x37.CMarketingMessages_GetMarketingMessagesForUser_Request\x1a\x38.CMarketingMessages_GetMarketingMessagesForUser_Response\"I\x82\xb5\x18\x45Get a list of active marketing messages filtered for a specific user.\x12\xbd\x01\n\x1aGetDisplayMarketingMessage\x12\x36.CMarketingMessages_GetDisplayMarketingMessage_Request\x1a\x37.CMarketingMessages_GetDisplayMarketingMessage_Response\".\x82\xb5\x18*Get a single marketing message, cacheable.\x12\x99\x01\n\x0fMarkMessageSeen\x12\x30.CMarketingMessages_MarkMessageSeen_Notification\x1a\x0b.NoResponse\"G\x82\xb5\x18\x43Mark that a user has viewed a message (so we won\'t show it again)\'.\x12\xcb\x01\n\x13GetMarketingMessage\x12/.CMarketingMessages_GetMarketingMessage_Request\x1a\x30.CMarketingMessages_GetMarketingMessage_Response\"Q\x82\xb5\x18MGet a single marketing message.  Admin account needed for non-active messages\x12\xa6\x01\n\x16\x43reateMarketingMessage\x12\x32.CMarketingMessages_CreateMarketingMessage_Request\x1a\x33.CMarketingMessages_CreateMarketingMessage_Response\"#\x82\xb5\x18\x1f\x43reate a new marketing message.\x12\xa2\x01\n\x16UpdateMarketingMessage\x12\x32.CMarketingMessages_UpdateMarketingMessage_Request\x1a\x33.CMarketingMessages_UpdateMarketingMessage_Response\"\x1f\x82\xb5\x18\x1bModify a marketing message.\x12\xa2\x01\n\x16\x44\x65leteMarketingMessage\x12\x32.CMarketingMessages_DeleteMarketingMessage_Request\x1a\x33.CMarketingMessages_DeleteMarketingMessage_Response\"\x1f\x82\xb5\x18\x1b\x44\x65lete a marketing message.\x12\xb5\x01\n\x15\x46indMarketingMessages\x12\x31.CMarketingMessages_FindMarketingMessages_Request\x1a\x32.CMarketingMessages_FindMarketingMessages_Response\"5\x82\xb5\x18\x31Search for marketing messages by name, type, etc.\x1a\x44\x82\xb5\x18@Marketing message data (\"Steam News\" updates at client startup).B\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,steammessages__storebrowse__pb2.DESCRIPTOR,])

_EMARKETINGMESSAGETYPE = _descriptor.EnumDescriptor(
  name='EMarketingMessageType',
  full_name='EMarketingMessageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageInvalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageNowAvailable', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageWeekendDeal', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessagePrePurchase', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessagePlayNow', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessagePreloadNow', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageGeneral', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageDemoQuit', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageGifting', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageEJsKorner', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3365,
  serialized_end=3727,
)
_sym_db.RegisterEnumDescriptor(_EMARKETINGMESSAGETYPE)

EMarketingMessageType = enum_type_wrapper.EnumTypeWrapper(_EMARKETINGMESSAGETYPE)
_EMARKETINGMESSAGEVISIBILITY = _descriptor.EnumDescriptor(
  name='EMarketingMessageVisibility',
  full_name='EMarketingMessageVisibility',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageVisibleBeta', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageVisiblePublic', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3729,
  serialized_end=3832,
)
_sym_db.RegisterEnumDescriptor(_EMARKETINGMESSAGEVISIBILITY)

EMarketingMessageVisibility = enum_type_wrapper.EnumTypeWrapper(_EMARKETINGMESSAGEVISIBILITY)
_EMARKETINGMESSAGEASSOCIATIONTYPE = _descriptor.EnumDescriptor(
  name='EMarketingMessageAssociationType',
  full_name='EMarketingMessageAssociationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageNoAssociation', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageAppAssociation', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageSubscriptionAssociation', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessagePublisherAssociation', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageGenreAssociation', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageBundleAssociation', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3835,
  serialized_end=4122,
)
_sym_db.RegisterEnumDescriptor(_EMARKETINGMESSAGEASSOCIATIONTYPE)

EMarketingMessageAssociationType = enum_type_wrapper.EnumTypeWrapper(_EMARKETINGMESSAGEASSOCIATIONTYPE)
_EMARKETINGMESSAGELOOKUPTYPE = _descriptor.EnumDescriptor(
  name='EMarketingMessageLookupType',
  full_name='EMarketingMessageLookupType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageLookupInvalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageLookupByGID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageLookupActive', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageLookupByTitleWithType', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMarketingMessageLookupByGIDList', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4125,
  serialized_end=4351,
)
_sym_db.RegisterEnumDescriptor(_EMARKETINGMESSAGELOOKUPTYPE)

EMarketingMessageLookupType = enum_type_wrapper.EnumTypeWrapper(_EMARKETINGMESSAGELOOKUPTYPE)
k_EMarketingMessageInvalid = 0
k_EMarketingMessageNowAvailable = 1
k_EMarketingMessageWeekendDeal = 2
k_EMarketingMessagePrePurchase = 3
k_EMarketingMessagePlayNow = 4
k_EMarketingMessagePreloadNow = 5
k_EMarketingMessageGeneral = 6
k_EMarketingMessageDemoQuit = 7
k_EMarketingMessageGifting = 8
k_EMarketingMessageEJsKorner = 9
k_EMarketingMessageVisibleBeta = 1
k_EMarketingMessageVisiblePublic = 2
k_EMarketingMessageNoAssociation = 0
k_EMarketingMessageAppAssociation = 1
k_EMarketingMessageSubscriptionAssociation = 2
k_EMarketingMessagePublisherAssociation = 3
k_EMarketingMessageGenreAssociation = 4
k_EMarketingMessageBundleAssociation = 5
k_EMarketingMessageLookupInvalid = 0
k_EMarketingMessageLookupByGID = 1
k_EMarketingMessageLookupActive = 2
k_EMarketingMessageLookupByTitleWithType = 3
k_EMarketingMessageLookupByGIDList = 4



_CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_GetActiveMarketingMessages_Request',
  full_name='CMarketingMessages_GetActiveMarketingMessages_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='CMarketingMessages_GetActiveMarketingMessages_Request.country', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=206,
)


_CMARKETINGMESSAGEPROTO = _descriptor.Descriptor(
  name='CMarketingMessageProto',
  full_name='CMarketingMessageProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessageProto.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CMarketingMessageProto.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMarketingMessageProto.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='CMarketingMessageProto.visibility', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='CMarketingMessageProto.priority', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='association_type', full_name='CMarketingMessageProto.association_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_id', full_name='CMarketingMessageProto.associated_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_name', full_name='CMarketingMessageProto.associated_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='CMarketingMessageProto.start_date', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='CMarketingMessageProto.end_date', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_allow', full_name='CMarketingMessageProto.country_allow', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_deny', full_name='CMarketingMessageProto.country_deny', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ownership_restrictions_overridden', full_name='CMarketingMessageProto.ownership_restrictions_overridden', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='must_own_appid', full_name='CMarketingMessageProto.must_own_appid', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='must_not_own_appid', full_name='CMarketingMessageProto.must_not_own_appid', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='must_own_packageid', full_name='CMarketingMessageProto.must_own_packageid', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='must_not_own_packageid', full_name='CMarketingMessageProto.must_not_own_packageid', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='must_have_launched_appid', full_name='CMarketingMessageProto.must_have_launched_appid', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_restrictions', full_name='CMarketingMessageProto.additional_restrictions', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template_type', full_name='CMarketingMessageProto.template_type', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template_vars', full_name='CMarketingMessageProto.template_vars', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMarketingMessageProto.flags', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_name', full_name='CMarketingMessageProto.creator_name', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=958,
)


_CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_GetActiveMarketingMessages_Response',
  full_name='CMarketingMessages_GetActiveMarketingMessages_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='CMarketingMessages_GetActiveMarketingMessages_Response.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_next_message_age', full_name='CMarketingMessages_GetActiveMarketingMessages_Response.time_next_message_age', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1091,
)


_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_GetMarketingMessagesForUser_Request',
  full_name='CMarketingMessages_GetMarketingMessagesForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_seen_messages', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.include_seen_messages', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elanguage', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.elanguage', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operating_system', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.operating_system', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023EOSType from client', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_package_version', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.client_package_version', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.context', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030BOptional, server can fill in from country code/language if not set', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_request', full_name='CMarketingMessages_GetMarketingMessagesForUser_Request.data_request', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%If passed, item data will be returned', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1509,
)


_CDISPLAYMARKETINGMESSAGE = _descriptor.Descriptor(
  name='CDisplayMarketingMessage',
  full_name='CDisplayMarketingMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CDisplayMarketingMessage.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CDisplayMarketingMessage.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='CDisplayMarketingMessage.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_item_id', full_name='CDisplayMarketingMessage.associated_item_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_item', full_name='CDisplayMarketingMessage.associated_item', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_name', full_name='CDisplayMarketingMessage.associated_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template_type', full_name='CDisplayMarketingMessage.template_type', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template_vars_json', full_name='CDisplayMarketingMessage.template_vars_json', index=7,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1787,
)


_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER = _descriptor.Descriptor(
  name='MarketingMessageForUser',
  full_name='CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='already_seen', full_name='CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser.already_seen', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1949,
  serialized_end=2040,
)

_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_GetMarketingMessagesForUser_Response',
  full_name='CMarketingMessages_GetMarketingMessagesForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='CMarketingMessages_GetMarketingMessagesForUser_Response.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=2040,
)


_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_GetDisplayMarketingMessage_Request',
  full_name='CMarketingMessages_GetDisplayMarketingMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_GetDisplayMarketingMessage_Request.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='CMarketingMessages_GetDisplayMarketingMessage_Request.context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_request', full_name='CMarketingMessages_GetDisplayMarketingMessage_Request.data_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%If passed, item data will be returned', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2043,
  serialized_end=2243,
)


_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_GetDisplayMarketingMessage_Response',
  full_name='CMarketingMessages_GetDisplayMarketingMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMarketingMessages_GetDisplayMarketingMessage_Response.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2245,
  serialized_end=2345,
)


_CMARKETINGMESSAGES_MARKMESSAGESEEN_NOTIFICATION = _descriptor.Descriptor(
  name='CMarketingMessages_MarkMessageSeen_Notification',
  full_name='CMarketingMessages_MarkMessageSeen_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_MarkMessageSeen_Notification.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2347,
  serialized_end=2409,
)


_CMARKETINGMESSAGES_GETMARKETINGMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_GetMarketingMessage_Request',
  full_name='CMarketingMessages_GetMarketingMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_GetMarketingMessage_Request.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=2472,
)


_CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_GetMarketingMessage_Response',
  full_name='CMarketingMessages_GetMarketingMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMarketingMessages_GetMarketingMessage_Response.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2474,
  serialized_end=2565,
)


_CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_CreateMarketingMessage_Request',
  full_name='CMarketingMessages_CreateMarketingMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMarketingMessages_CreateMarketingMessage_Request.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2567,
  serialized_end=2660,
)


_CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_CreateMarketingMessage_Response',
  full_name='CMarketingMessages_CreateMarketingMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_CreateMarketingMessage_Response.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2727,
)


_CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_UpdateMarketingMessage_Request',
  full_name='CMarketingMessages_UpdateMarketingMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_UpdateMarketingMessage_Request.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMarketingMessages_UpdateMarketingMessage_Request.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2729,
  serialized_end=2835,
)


_CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_UpdateMarketingMessage_Response',
  full_name='CMarketingMessages_UpdateMarketingMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2837,
  serialized_end=2889,
)


_CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_DeleteMarketingMessage_Request',
  full_name='CMarketingMessages_DeleteMarketingMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_DeleteMarketingMessage_Request.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2891,
  serialized_end=2955,
)


_CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_DeleteMarketingMessage_Response',
  full_name='CMarketingMessages_DeleteMarketingMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2957,
  serialized_end=3009,
)


_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST = _descriptor.Descriptor(
  name='CMarketingMessages_FindMarketingMessages_Request',
  full_name='CMarketingMessages_FindMarketingMessages_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lookup_type', full_name='CMarketingMessages_FindMarketingMessages_Request.lookup_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMarketingMessages_FindMarketingMessages_Request.gid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='CMarketingMessages_FindMarketingMessages_Request.message_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidlist', full_name='CMarketingMessages_FindMarketingMessages_Request.gidlist', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CMarketingMessages_FindMarketingMessages_Request.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3012,
  serialized_end=3266,
)


_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE = _descriptor.Descriptor(
  name='CMarketingMessages_FindMarketingMessages_Response',
  full_name='CMarketingMessages_FindMarketingMessages_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='CMarketingMessages_FindMarketingMessages_Response.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3268,
  serialized_end=3362,
)

_CMARKETINGMESSAGEPROTO.fields_by_name['type'].enum_type = _EMARKETINGMESSAGETYPE
_CMARKETINGMESSAGEPROTO.fields_by_name['visibility'].enum_type = _EMARKETINGMESSAGEVISIBILITY
_CMARKETINGMESSAGEPROTO.fields_by_name['association_type'].enum_type = _EMARKETINGMESSAGEASSOCIATIONTYPE
_CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE.fields_by_name['messages'].message_type = _CMARKETINGMESSAGEPROTO
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST.fields_by_name['context'].message_type = steammessages__storebrowse__pb2._STOREBROWSECONTEXT
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST.fields_by_name['data_request'].message_type = steammessages__storebrowse__pb2._STOREBROWSEITEMDATAREQUEST
_CDISPLAYMARKETINGMESSAGE.fields_by_name['type'].enum_type = _EMARKETINGMESSAGETYPE
_CDISPLAYMARKETINGMESSAGE.fields_by_name['associated_item_id'].message_type = steammessages__storebrowse__pb2._STOREITEMID
_CDISPLAYMARKETINGMESSAGE.fields_by_name['associated_item'].message_type = steammessages__storebrowse__pb2._STOREITEM
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER.fields_by_name['message'].message_type = _CDISPLAYMARKETINGMESSAGE
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER.containing_type = _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE.fields_by_name['messages'].message_type = _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER
_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST.fields_by_name['context'].message_type = steammessages__storebrowse__pb2._STOREBROWSECONTEXT
_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST.fields_by_name['data_request'].message_type = steammessages__storebrowse__pb2._STOREBROWSEITEMDATAREQUEST
_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE.fields_by_name['message'].message_type = _CDISPLAYMARKETINGMESSAGE
_CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE.fields_by_name['message'].message_type = _CMARKETINGMESSAGEPROTO
_CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST.fields_by_name['message'].message_type = _CMARKETINGMESSAGEPROTO
_CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST.fields_by_name['message'].message_type = _CMARKETINGMESSAGEPROTO
_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST.fields_by_name['lookup_type'].enum_type = _EMARKETINGMESSAGELOOKUPTYPE
_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST.fields_by_name['message_type'].enum_type = _EMARKETINGMESSAGETYPE
_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE.fields_by_name['messages'].message_type = _CMARKETINGMESSAGEPROTO
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetActiveMarketingMessages_Request'] = _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessageProto'] = _CMARKETINGMESSAGEPROTO
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetActiveMarketingMessages_Response'] = _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetMarketingMessagesForUser_Request'] = _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CDisplayMarketingMessage'] = _CDISPLAYMARKETINGMESSAGE
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetMarketingMessagesForUser_Response'] = _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetDisplayMarketingMessage_Request'] = _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetDisplayMarketingMessage_Response'] = _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_MarkMessageSeen_Notification'] = _CMARKETINGMESSAGES_MARKMESSAGESEEN_NOTIFICATION
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetMarketingMessage_Request'] = _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessages_GetMarketingMessage_Response'] = _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_CreateMarketingMessage_Request'] = _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessages_CreateMarketingMessage_Response'] = _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_UpdateMarketingMessage_Request'] = _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessages_UpdateMarketingMessage_Response'] = _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_DeleteMarketingMessage_Request'] = _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessages_DeleteMarketingMessage_Response'] = _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CMarketingMessages_FindMarketingMessages_Request'] = _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST
DESCRIPTOR.message_types_by_name['CMarketingMessages_FindMarketingMessages_Response'] = _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE
DESCRIPTOR.enum_types_by_name['EMarketingMessageType'] = _EMARKETINGMESSAGETYPE
DESCRIPTOR.enum_types_by_name['EMarketingMessageVisibility'] = _EMARKETINGMESSAGEVISIBILITY
DESCRIPTOR.enum_types_by_name['EMarketingMessageAssociationType'] = _EMARKETINGMESSAGEASSOCIATIONTYPE
DESCRIPTOR.enum_types_by_name['EMarketingMessageLookupType'] = _EMARKETINGMESSAGELOOKUPTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMarketingMessages_GetActiveMarketingMessages_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetActiveMarketingMessages_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetActiveMarketingMessages_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetActiveMarketingMessages_Request)

CMarketingMessageProto = _reflection.GeneratedProtocolMessageType('CMarketingMessageProto', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGEPROTO,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessageProto)
  })
_sym_db.RegisterMessage(CMarketingMessageProto)

CMarketingMessages_GetActiveMarketingMessages_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetActiveMarketingMessages_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetActiveMarketingMessages_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetActiveMarketingMessages_Response)

CMarketingMessages_GetMarketingMessagesForUser_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetMarketingMessagesForUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetMarketingMessagesForUser_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetMarketingMessagesForUser_Request)

CDisplayMarketingMessage = _reflection.GeneratedProtocolMessageType('CDisplayMarketingMessage', (_message.Message,), {
  'DESCRIPTOR' : _CDISPLAYMARKETINGMESSAGE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDisplayMarketingMessage)
  })
_sym_db.RegisterMessage(CDisplayMarketingMessage)

CMarketingMessages_GetMarketingMessagesForUser_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetMarketingMessagesForUser_Response', (_message.Message,), {

  'MarketingMessageForUser' : _reflection.GeneratedProtocolMessageType('MarketingMessageForUser', (_message.Message,), {
    'DESCRIPTOR' : _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER,
    '__module__' : 'steammessages_marketingmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser)
    })
  ,
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetMarketingMessagesForUser_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetMarketingMessagesForUser_Response)
_sym_db.RegisterMessage(CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser)

CMarketingMessages_GetDisplayMarketingMessage_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetDisplayMarketingMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetDisplayMarketingMessage_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetDisplayMarketingMessage_Request)

CMarketingMessages_GetDisplayMarketingMessage_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetDisplayMarketingMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetDisplayMarketingMessage_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetDisplayMarketingMessage_Response)

CMarketingMessages_MarkMessageSeen_Notification = _reflection.GeneratedProtocolMessageType('CMarketingMessages_MarkMessageSeen_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_MARKMESSAGESEEN_NOTIFICATION,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_MarkMessageSeen_Notification)
  })
_sym_db.RegisterMessage(CMarketingMessages_MarkMessageSeen_Notification)

CMarketingMessages_GetMarketingMessage_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetMarketingMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetMarketingMessage_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetMarketingMessage_Request)

CMarketingMessages_GetMarketingMessage_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_GetMarketingMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_GetMarketingMessage_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_GetMarketingMessage_Response)

CMarketingMessages_CreateMarketingMessage_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_CreateMarketingMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_CreateMarketingMessage_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_CreateMarketingMessage_Request)

CMarketingMessages_CreateMarketingMessage_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_CreateMarketingMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_CreateMarketingMessage_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_CreateMarketingMessage_Response)

CMarketingMessages_UpdateMarketingMessage_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_UpdateMarketingMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_UpdateMarketingMessage_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_UpdateMarketingMessage_Request)

CMarketingMessages_UpdateMarketingMessage_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_UpdateMarketingMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_UpdateMarketingMessage_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_UpdateMarketingMessage_Response)

CMarketingMessages_DeleteMarketingMessage_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_DeleteMarketingMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_DeleteMarketingMessage_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_DeleteMarketingMessage_Request)

CMarketingMessages_DeleteMarketingMessage_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_DeleteMarketingMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_DeleteMarketingMessage_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_DeleteMarketingMessage_Response)

CMarketingMessages_FindMarketingMessages_Request = _reflection.GeneratedProtocolMessageType('CMarketingMessages_FindMarketingMessages_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_FindMarketingMessages_Request)
  })
_sym_db.RegisterMessage(CMarketingMessages_FindMarketingMessages_Request)

CMarketingMessages_FindMarketingMessages_Response = _reflection.GeneratedProtocolMessageType('CMarketingMessages_FindMarketingMessages_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE,
  '__module__' : 'steammessages_marketingmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMarketingMessages_FindMarketingMessages_Response)
  })
_sym_db.RegisterMessage(CMarketingMessages_FindMarketingMessages_Response)


DESCRIPTOR._options = None
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST.fields_by_name['operating_system']._options = None
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST.fields_by_name['context']._options = None
_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST.fields_by_name['data_request']._options = None
_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST.fields_by_name['data_request']._options = None

_MARKETINGMESSAGES = _descriptor.ServiceDescriptor(
  name='MarketingMessages',
  full_name='MarketingMessages',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030@Marketing message data (\"Steam News\" updates at client startup).',
  create_key=_descriptor._internal_create_key,
  serialized_start=4354,
  serialized_end=6092,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetActiveMarketingMessages',
    full_name='MarketingMessages.GetActiveMarketingMessages',
    index=0,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_REQUEST,
    output_type=_CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE,
    serialized_options=b'\202\265\030(Get a list of active marketing messages.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMarketingMessagesForUser',
    full_name='MarketingMessages.GetMarketingMessagesForUser',
    index=1,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST,
    output_type=_CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE,
    serialized_options=b'\202\265\030EGet a list of active marketing messages filtered for a specific user.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDisplayMarketingMessage',
    full_name='MarketingMessages.GetDisplayMarketingMessage',
    index=2,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST,
    output_type=_CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030*Get a single marketing message, cacheable.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MarkMessageSeen',
    full_name='MarketingMessages.MarkMessageSeen',
    index=3,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_MARKMESSAGESEEN_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030CMark that a user has viewed a message (so we won\'t show it again)\'.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMarketingMessage',
    full_name='MarketingMessages.GetMarketingMessage',
    index=4,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_GETMARKETINGMESSAGE_REQUEST,
    output_type=_CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030MGet a single marketing message.  Admin account needed for non-active messages',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateMarketingMessage',
    full_name='MarketingMessages.CreateMarketingMessage',
    index=5,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST,
    output_type=_CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030\037Create a new marketing message.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMarketingMessage',
    full_name='MarketingMessages.UpdateMarketingMessage',
    index=6,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST,
    output_type=_CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030\033Modify a marketing message.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMarketingMessage',
    full_name='MarketingMessages.DeleteMarketingMessage',
    index=7,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_REQUEST,
    output_type=_CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030\033Delete a marketing message.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindMarketingMessages',
    full_name='MarketingMessages.FindMarketingMessages',
    index=8,
    containing_service=None,
    input_type=_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST,
    output_type=_CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE,
    serialized_options=b'\202\265\0301Search for marketing messages by name, type, etc.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MARKETINGMESSAGES)

DESCRIPTOR.services_by_name['MarketingMessages'] = _MARKETINGMESSAGES

MarketingMessages = service_reflection.GeneratedServiceType('MarketingMessages', (_service.Service,), dict(
  DESCRIPTOR = _MARKETINGMESSAGES,
  __module__ = 'steammessages_marketingmessages_pb2'
  ))

MarketingMessages_Stub = service_reflection.GeneratedServiceStubType('MarketingMessages_Stub', (MarketingMessages,), dict(
  DESCRIPTOR = _MARKETINGMESSAGES,
  __module__ = 'steammessages_marketingmessages_pb2'
  ))


# @@protoc_insertion_point(module_scope)
